==> scummvm_2.1.1+dfsg1.orig.tar.xz: scummvm-2.1.1/engines/mutationofjb/assets.cpp <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 */

#include "mutationofjb/assets.h"

namespace MutationOfJB {

Assets::Assets(Game &game) : _game(game), _toSayList("tosay.ger"), _responseList("response.ger"), _hardcodedStrings(game) {}

Font &Assets::getSystemFont() {
	return _systemFont;
}

Font &Assets::getSpeechFont() {
	return _speechFont;
}

ConversationLineList &Assets::getToSayList() {
	return _toSayList;
}

ConversationLineList &Assets::getResponseList() {
	return _responseList;
}

InventoryItemDefinitionList &Assets::getInventoryItemDefList() {
	return _invItemDefList;
}

HardcodedStrings &Assets::getHardcodedStrings() {
	return _hardcodedStrings;
}

}

==> scummvm_2.2.0+dfsg1.orig.tar.xz: scummvm-2.2.0/engines/mutationofjb/assets.cpp <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 */

#include "mutationofjb/assets.h"

namespace MutationOfJB {

Assets::Assets(Game &game) : _toSayList("tosay.ger"), _responseList("response.ger"), _hardcodedStrings(game) {}

Font &Assets::getSystemFont() {
	return _systemFont;
}

Font &Assets::getSpeechFont() {
	return _speechFont;
}

ConversationLineList &Assets::getToSayList() {
	return _toSayList;
}

ConversationLineList &Assets::getResponseList() {
	return _responseList;
}

InventoryItemDefinitionList &Assets::getInventoryItemDefList() {
	return _invItemDefList;
}

HardcodedStrings &Assets::getHardcodedStrings() {
	return _hardcodedStrings;
}

}
